@@ -1,3 +1,10 @@
+#ifndef WIN32
+#ifndef _CRT_SECURE_NO_WARNINGS
+// silence warnings about getenv, strncpy, etc.
+#define _CRT_SECURE_NO_WARNINGS
+#endif
+#endif
+
 // Bindings
 #include "capi.h"
 #include "cpp_cppyy.h"
@@ -225,7 +232,7 @@ public:
 
     // setup dummy holders for global and std namespaces
         assert(g_classrefs.size() == GLOBAL_HANDLE);
-        g_name2classrefidx[""]      = GLOBAL_HANDLE;
+        g_name2classrefidx[""]     = GLOBAL_HANDLE;
         g_classrefs.push_back(TClassRef(""));
 
     // aliases for std (setup already in pythonify)
@@ -437,14 +444,6 @@ std::string Cppyy::ResolveName(const std::string& cppitem_name)
         pos += 2;
     }
 
-#ifdef _WIN32
-// TODO: this is a bug somewhere deep in Clang's type printing; since we're close
-// to upgrading to Clang9, this hack will have to do.
-    pos = tclean.find("std::basic_string<char,std::allocator<char>,std::allocator<char> >");
-    if (pos != std::string::npos)
-        tclean = tclean.substr(0, pos+28) + "char_traits" + tclean.substr(pos+37, std::string::npos);
-#endif
-
     if (tclean.compare(0, 6, "const ") != 0)
         return TClassEdit::ShortType(tclean.c_str(), 2);
     return "const " + TClassEdit::ShortType(tclean.c_str(), 2);
@@ -554,10 +553,13 @@ Cppyy::TCppScope_t Cppyy::GetScope(const std::string& sname)
 // TODO: scope_name should always be final already?
 // Resolve name fully before lookup to make sure all aliases point to the same scope
     std::string scope_name = ResolveName(sname);
-    bool bHasAlias = sname != scope_name;
-    if (bHasAlias) {
+    bool bHasAlias1 = sname != scope_name;
+    if (bHasAlias1) {
         result = find_memoized(scope_name);
-        if (result) return result;
+        if (result) {
+            g_name2classrefidx[sname] = result;
+            return result;
+        }
     }
 
 // use TClass directly, to enable auto-loading; class may be stubbed (eg. for
@@ -568,9 +570,20 @@ Cppyy::TCppScope_t Cppyy::GetScope(const std::string& sname)
         return (TCppScope_t)0;
 
 // memoize found/created TClass
+    bool bHasAlias2 = cr->GetName() != scope_name;
+    if (bHasAlias2) {
+        result = find_memoized(cr->GetName());
+        if (result) {
+            g_name2classrefidx[scope_name] = result;
+            if (bHasAlias1) g_name2classrefidx[sname] = result;
+            return result;
+        }
+    }
+
     ClassRefs_t::size_type sz = g_classrefs.size();
     g_name2classrefidx[scope_name] = sz;
-    if (bHasAlias) g_name2classrefidx[sname] = sz;
+    if (bHasAlias1) g_name2classrefidx[sname] = sz;
+    if (bHasAlias2) g_name2classrefidx[cr->GetName()] = sz;
     g_classrefs.push_back(TClassRef(scope_name.c_str()));
 
     return (TCppScope_t)sz;
@@ -2221,12 +2234,12 @@ Cppyy::TCppIndex_t Cppyy::GetNumEnumData(TCppEnum_t etype)
 
 std::string Cppyy::GetEnumDataName(TCppEnum_t etype, TCppIndex_t idata)
 {
-    return ((TEnumConstant*)((TEnum*)etype)->GetConstants()->At(idata))->GetName();
+    return ((TEnumConstant*)((TEnum*)etype)->GetConstants()->At((int)idata))->GetName();
 }
 
 long long Cppyy::GetEnumDataValue(TCppEnum_t etype, TCppIndex_t idata)
 {
-     TEnumConstant* ecst = (TEnumConstant*)((TEnum*)etype)->GetConstants()->At(idata);
+     TEnumConstant* ecst = (TEnumConstant*)((TEnum*)etype)->GetConstants()->At((int)idata);
      return (long long)ecst->GetValue();
 }
 
